@@ -1,7 +1,7 @@
 test_that("msigdbr_collections()", {
   skip_if_not_installed("msigdbdf")
   collections <- msigdbr_collections()
-  expect_s3_class(collections, "tbl_df")
+  expect_s3_class(collections, "data.frame")
   expect_gt(nrow(collections), 10)
   expect_lt(nrow(collections), 30)
   expect_match(collections$gs_collection, "H", fixed = TRUE, all = FALSE)
@@ -13,13 +13,13 @@ test_that("msigdbr_collections()", {
 test_that("msigdbr_collections() db_species", {
   skip_if_not_installed("msigdbdf")
   chs <- msigdbr_collections(db_species = "Hs")
-  expect_s3_class(chs, "tbl_df")
+  expect_s3_class(chs, "data.frame")
   expect_gt(nrow(chs), 10)
   expect_lt(nrow(chs), 30)
   expect_match(chs$gs_collection, "H", fixed = TRUE, all = FALSE)
   expect_match(chs$gs_collection, "C8", fixed = TRUE, all = FALSE)
   cmm <- msigdbr_collections(db_species = "Mm")
-  expect_s3_class(cmm, "tbl_df")
+  expect_s3_class(cmm, "data.frame")
   expect_gt(nrow(cmm), 10)
   expect_lt(nrow(cmm), 30)
   expect_match(cmm$gs_collection, "MH", fixed = TRUE, all = FALSE)
